<?php # $Id: serendipity_define.js.php 1055 2006-04-06 09:14:11Z garvinhicking $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
/* vim: set sts=4 ts=4 expandtab : */

header('Content-type: application/x-javascript');
include('serendipity_config.inc.php');
?>
<!-- // Hide from older browsers
// This page serves to carry through any variables without having to parse a complete .js file as .php

var XHTML11 = true;

// -->
